pub struct CurrentDispatcher;Expand description
A placeholder for the currently active dispatcher. Use
GetAsyncDispatcher::get_async_dispatcher to access it when needed.
Implementations
Sourceimpl CurrentDispatcher
impl CurrentDispatcher
Sourcepub unsafe fn set(dispatcher: &impl AsAsyncDispatcherRef)
pub unsafe fn set(dispatcher: &impl AsAsyncDispatcherRef)
Sets the currently active dispatcher for this thread.
Safety
The caller must ensure that the dispatcher they set will be alive until it is Self::unset
or Self::set to another value. Using Self::with is a safer way to use this api as
it will use the current execution stack to ensure that it is properly unset.
Sourcepub fn with<R>(
dispatcher: &impl AsAsyncDispatcherRef,
f: impl FnOnce() -> R,
) -> R
pub fn with<R>( dispatcher: &impl AsAsyncDispatcherRef, f: impl FnOnce() -> R, ) -> R
Runs the passed function with the current dispatcher set to the one passed in, and then re-sets the dispatcher to whatever it was before.